@@ -15,12 +15,10 @@ from langchain_core.runnables import RunnableSerializable
 from agentuniverse.agent.action.knowledge.knowledge import Knowledge
 from agentuniverse.agent.action.knowledge.knowledge_manager import KnowledgeManager
 from agentuniverse.agent.action.knowledge.store.document import Document
-from agentuniverse.agent.action.knowledge.store.query import Query
 from agentuniverse.agent.action.tool.tool_manager import ToolManager
 from agentuniverse.agent.agent_manager import AgentManager
 from agentuniverse.agent.agent_model import AgentModel
 from agentuniverse.agent.input_object import InputObject
-from agentuniverse.agent.memory.chat_memory import ChatMemory
 from agentuniverse.agent.memory.memory import Memory
 from agentuniverse.agent.memory.message import Message
 from agentuniverse.agent.memory.memory_manager import MemoryManager
@@ -30,7 +28,7 @@ from agentuniverse.base.config.component_configer.configers.planner_configer imp
 from agentuniverse.llm.llm import LLM
 from agentuniverse.llm.llm_manager import LLMManager
 from agentuniverse.prompt.prompt import Prompt
-from agentuniverse.base.util.memory_util import generate_messages, generate_memories
+from agentuniverse.base.util.memory_util import generate_messages, get_memory_string
 
 logging.getLogger().setLevel(logging.ERROR)
 
@@ -65,7 +63,7 @@ class Planner(ComponentBase):
         """
         pass
 
-    def handle_memory(self, agent_model: AgentModel, planner_input: dict) -> ChatMemory | None:
+    def handle_memory(self, agent_model: AgentModel, planner_input: dict) -> Memory | None:
         """Memory module processing.
 
         Args:
@@ -76,20 +74,23 @@ class Planner(ComponentBase):
         """
         chat_history: list = planner_input.get('chat_history')
         memory_name = agent_model.memory.get('name')
-        llm_model = agent_model.memory.get('llm_model') or dict()
-        llm_name = llm_model.get('name') or agent_model.profile.get('llm_model').get('name')
 
-        messages: list[Message] = generate_messages(chat_history)
-        llm: LLM = LLMManager().get_instance_obj(llm_name)
-        params: dict = dict()
-        params['messages'] = messages
-        params['llm'] = llm
-        params['input_key'] = self.input_key
-        params['output_key'] = self.output_key
-
-        memory: ChatMemory = MemoryManager().get_instance_obj(component_instance_name=memory_name)
+        # get memory instance
+        memory: Memory = MemoryManager().get_instance_obj(component_instance_name=memory_name)
         if memory is None:
             return None
+
+        # generate a list of temporary messages from the given chat history and add them to the memory instance.
+        temporary_messages: list[Message] = generate_messages(chat_history)
+        if temporary_messages:
+            memory.add(temporary_messages, **planner_input)
+
+        llm_name = agent_model.profile.get('llm_model', {}).get('name')
+        llm: LLM = LLMManager().get_instance_obj(llm_name)
+
+        params: dict = dict()
+        params['llm'] = llm
+        params['agent_llm_name'] = llm_name
         return memory.set_by_agent_model(**params)
 
     def run_all_actions(self, agent_model: AgentModel, planner_input: dict, input_object: InputObject):
@@ -118,10 +119,11 @@ class Planner(ComponentBase):
             knowledge: Knowledge = KnowledgeManager().get_instance_obj(knowledge_name)
             if knowledge is None:
                 continue
-            knowledge_res: List[Document] = knowledge.store.query(
-                Query(query_str=input_object.get_data(self.input_key), similarity_top_k=2), **input_object.to_dict())
-            for document in knowledge_res:
-                action_result.append(document.text)
+            knowledge_res: List[Document] = knowledge.query_knowledge(
+                query_str=input_object.get_data(self.input_key),
+                **input_object.to_dict()
+            )
+            action_result.append(knowledge.to_llm(knowledge_res))
 
         for agent_name in agents:
             agent = AgentManager().get_instance_obj(agent_name)
@@ -156,7 +158,7 @@ class Planner(ComponentBase):
         """
         llm_name = agent_model.profile.get('llm_model').get('name')
         llm: LLM = LLMManager().get_instance_obj(component_instance_name=llm_name)
-        return llm.set_by_agent_model(**agent_model.profile.get('llm_model'))
+        return llm
 
     def initialize_by_component_configer(self, component_configer: PlannerConfiger) -> 'Planner':
         """Initialize the planner by the PlannerConfiger object.
@@ -185,8 +187,9 @@ class Planner(ComponentBase):
             return
         output_stream.put_nowait(data)
 
-    def invoke_chain(self, agent_model: AgentModel, chain: RunnableSerializable[Any, str], planner_input: dict, chat_history,
-               input_object: InputObject):
+    def invoke_chain(self, agent_model: AgentModel, chain: RunnableSerializable[Any, str], planner_input: dict,
+                     chat_history,
+                     input_object: InputObject):
 
         if not input_object.get_data('output_stream'):
             res = chain.invoke(input=planner_input, config={"configurable": {"session_id": "unused"}})
@@ -202,4 +205,3 @@ class Planner(ComponentBase):
             })
             result.append(token)
         return "".join(result)
-
