@@ -5,11 +5,17 @@
 # @Author  : wangchongshi
 # @Email   : wangchongshi.wcs@antgroup.com
 # @FileName: react_planner.py
+from typing import Sequence, Optional, Union, List
 
-from langchain_core.chat_history import InMemoryChatMessageHistory
-from langchain.agents import AgentExecutor, create_react_agent
+from langchain.agents.format_scratchpad import format_log_to_str
+from langchain.agents.output_parsers import ReActSingleInputOutputParser
+
+from langchain.agents import AgentExecutor, AgentOutputParser
 from langchain.tools import Tool as LangchainTool
-from langchain_core.runnables import RunnableConfig
+from langchain_core.language_models import BaseLanguageModel
+from langchain_core.prompts import BasePromptTemplate
+from langchain_core.runnables import RunnableConfig, RunnablePassthrough, Runnable
+from langchain_core.tools import BaseTool, ToolsRenderer, render_text_description
 
 from agentuniverse.agent.action.knowledge.knowledge import Knowledge
 from agentuniverse.agent.action.knowledge.knowledge_manager import KnowledgeManager
@@ -19,9 +25,11 @@ from agentuniverse.agent.agent import Agent
 from agentuniverse.agent.agent_manager import AgentManager
 from agentuniverse.agent.agent_model import AgentModel
 from agentuniverse.agent.input_object import InputObject
-from agentuniverse.agent.memory.chat_memory import ChatMemory
+from agentuniverse.agent.memory.memory import Memory
 from agentuniverse.agent.plan.planner.planner import Planner
-from agentuniverse.agent.plan.planner.react_planner.stream_callback import StreamOutPutCallbackHandler
+from agentuniverse.agent.plan.planner.react_planner.stream_callback import StreamOutPutCallbackHandler, \
+    InvokeCallbackHandler
+from agentuniverse.base.util.agent_util import assemble_memory_input
 from agentuniverse.base.util.prompt_util import process_llm_token
 from agentuniverse.llm.llm import LLM
 from agentuniverse.prompt.chat_prompt import ChatPrompt
@@ -47,24 +55,26 @@ class ReActPlanner(Planner):
             dict: The planner result.
         """
 
-        memory: ChatMemory = self.handle_memory(agent_model, planner_input)
+        memory: Memory = self.handle_memory(agent_model, planner_input)
 
         llm: LLM = self.handle_llm(agent_model)
-
         tools = self.acquire_tools(agent_model.action)
-
         prompt: Prompt = self.handle_prompt(agent_model, planner_input)
         process_llm_token(llm, prompt.as_langchain(), agent_model.profile, planner_input)
-        chat_history = memory.as_langchain().chat_memory if memory else InMemoryChatMessageHistory()
-
-        agent = create_react_agent(llm.as_langchain(), tools, prompt.as_langchain())
+        assemble_memory_input(memory, planner_input)
+        stop_sequence = []
+        if agent_model.plan.get('stop_sequence'):
+            stop_sequence = agent_model.profile.get('stop_sequence')
+        agent = create_react_agent(llm.as_langchain(), tools, prompt.as_langchain(), stop_sequence=stop_sequence,
+                                   bind_params=agent_model.llm_params())
         agent_executor = AgentExecutor(agent=agent, tools=tools,
                                        verbose=True,
                                        handle_parsing_errors=True,
                                        max_iterations=agent_model.plan.get('planner').get("max_iterations", 15))
 
         return agent_executor.invoke(input=planner_input, memory=memory.as_langchain() if memory else None,
-                                     chat_history=chat_history, config=self.get_run_config(agent_model, input_object))
+                                     chat_history=planner_input.get(memory.memory_key) if memory else '',
+                                     config=self.get_run_config(agent_model, input_object))
 
     @staticmethod
     def get_run_config(agent_model: AgentModel, input_object: InputObject) -> RunnableConfig:
@@ -72,6 +82,8 @@ class ReActPlanner(Planner):
         callbacks = []
         output_stream = input_object.get_data('output_stream')
         callbacks.append(StreamOutPutCallbackHandler(output_stream, agent_info=agent_model.info))
+        callbacks.append(InvokeCallbackHandler(source=agent_model.info.get('name'),
+                                               llm_name=agent_model.profile.get('llm_model').get('name')))
         config.setdefault("callbacks", callbacks)
         return config
 
@@ -133,3 +145,40 @@ class ReActPlanner(Planner):
 
         prompt = Prompt().build_prompt(profile_prompt_model, self.prompt_assemble_order)
         return prompt
+
+
+def create_react_agent(
+        llm: BaseLanguageModel,
+        tools: Sequence[BaseTool],
+        prompt: BasePromptTemplate,
+        output_parser: Optional[AgentOutputParser] = None,
+        tools_renderer: ToolsRenderer = render_text_description,
+        *,
+        stop_sequence: Union[bool, List[str]] = True,
+        bind_params: Optional[dict],
+) -> Runnable:
+    missing_vars = {"tools", "tool_names", "agent_scratchpad"}.difference(
+        prompt.input_variables + list(prompt.partial_variables)
+    )
+    if missing_vars:
+        raise ValueError(f"Prompt missing required variables: {missing_vars}")
+
+    prompt = prompt.partial(
+        tools=tools_renderer(list(tools)),
+        tool_names=", ".join([t.name for t in tools]),
+    )
+    if stop_sequence:
+        stop = ["\nObservation"] if stop_sequence is True else stop_sequence
+        llm_with_stop = llm.bind(stop=stop, **(bind_params or {}))
+    else:
+        llm_with_stop = llm.bind(**(bind_params or {}))
+    output_parser = output_parser or ReActSingleInputOutputParser()
+    agent = (
+            RunnablePassthrough.assign(
+                agent_scratchpad=lambda x: format_log_to_str(x["intermediate_steps"]),
+            )
+            | prompt
+            | llm_with_stop
+            | output_parser
+    )
+    return agent
