@@ -5,8 +5,9 @@
 # @Author  : fanen.lhy
 # @Email   : fanen.lhy@antgroup.com
 # @FileName: request_task.py
-
+import asyncio
 import enum
+import traceback
 from enum import Enum
 import json
 import queue
@@ -14,12 +15,13 @@ import time
 import uuid
 from datetime import datetime, timedelta
 from threading import Thread
-from typing import Optional
+from typing import Optional, AsyncIterator
 
 from .dal.request_library import RequestLibrary
 from .dal.entity.request_do import RequestDO
 from .thread_with_result import ThreadWithReturnValue
 from agentuniverse.base.util.logging.logging_util import LOGGER
+from ...agent.output_object import OutputObject
 
 EOF_SIGNAL = '{"type": "EOF"}'
 
@@ -54,12 +56,14 @@ class RequestTask:
         self.func: callable = func
         self.kwargs = kwargs
         self.request_id = uuid.uuid4().hex
-        self.queue = queue.Queue(maxsize=100)
+        self.queue = queue.Queue(maxsize=1000)
         self.thread: Optional[ThreadWithReturnValue] = None
         self.state = TaskStateEnum.INIT.value
         # Whether save to Database.
         self.saved = saved
         self.__request_do__ = self.add_request_do()
+        self.async_queue = asyncio.Queue(maxsize=2000)
+        self.async_task = None
 
     def receive_steps(self):
         """Yield the stream data by getting data from the queue."""
@@ -75,12 +79,40 @@ class RequestTask:
             return
         try:
             result = self.thread.result()
+            if isinstance(result, OutputObject):
+                result = result.to_dict()
             yield "data:" + json.dumps({"result": result},
                                        ensure_ascii=False) + "\n\n "
         except Exception as e:
-            LOGGER.error("request task execute Fail: " + str(e))
+            LOGGER.error("request task execute Fail: " + str(e)+traceback.format_exc())
             yield "data:" + json.dumps({"error": {"error_msg": str(e)}}) + "\n\n "
 
+    async def async_receive_steps(self) -> AsyncIterator[str]:
+        while True:
+            try:
+                output: str = await asyncio.wait_for(self.async_queue.get(), timeout=0.5)
+            except asyncio.TimeoutError:
+                await asyncio.sleep(1)
+                print("Waiting for data timed out. Retrying...")
+                continue
+            if output is None:
+                break
+            if output == EOF_SIGNAL:
+                break
+            yield "data:" + json.dumps({"process": output},
+                                       ensure_ascii=False) + "\n\n"
+        if self.canceled():
+            return
+        try:
+            result = await self.async_task
+            if isinstance(result, OutputObject):
+                result = result.to_dict()
+            yield "data:" + json.dumps({"result": result},
+                                       ensure_ascii=False) + "\n\n"
+        except Exception as e:
+            LOGGER.error("request task execute Fail: " + str(e))
+            yield "data:" + json.dumps({"error": {"error_msg": str(e)}}) + "\n\n"
+
     def append_steps(self):
         """Tracing async service running state and update it to database."""
         try:
@@ -122,11 +154,19 @@ class RequestTask:
     def stream_run(self):
         """Run the service in a separate thread and yield result stream."""
         self.kwargs['output_stream'] = self.queue
+
         self.thread = ThreadWithReturnValue(target=self.func,
                                             kwargs=self.kwargs)
         self.thread.start()
         return self.receive_steps()
 
+    async def async_stream_run(self) -> AsyncIterator[str]:
+        self.kwargs['output_stream'] = self.async_queue
+        loop = asyncio.get_event_loop()
+        self.async_task = loop.create_task(self.func(**self.kwargs))
+        async for item in self.async_receive_steps():
+            yield item
+
     def run(self):
         """Run the service synchronous and return the result."""
         self.next_state(TaskStateEnum.RUNNING)
@@ -188,8 +228,8 @@ class RequestTask:
             result=dict(),
             steps=[],
             additional_args=dict(),
-            gmt_create=int(time.time()),
-            gmt_modified=int(time.time()),
+            gmt_create=datetime.now(),
+            gmt_modified=datetime.now(),
         )
         if self.saved:
             RequestLibrary().add_request(request_do)
